@@ -35,19 +35,19 @@ class PowerDevilDPMSAction : public PowerDevil::Action
 
 public:
     explicit PowerDevilDPMSAction(QObject *parent, const QVariantList &);
-    virtual ~PowerDevilDPMSAction();
+    ~PowerDevilDPMSAction() override;
 
 protected:
-    void onProfileUnload() Q_DECL_OVERRIDE;
-    bool onUnloadAction() Q_DECL_OVERRIDE;
-    void onWakeupFromIdle() Q_DECL_OVERRIDE;
-    void onIdleTimeout(int msec) Q_DECL_OVERRIDE;
-    void onProfileLoad() Q_DECL_OVERRIDE;
-    void triggerImpl(const QVariantMap &args) Q_DECL_OVERRIDE;
-    bool isSupported() Q_DECL_OVERRIDE;
+    void onProfileUnload() override;
+    bool onUnloadAction() override;
+    void onWakeupFromIdle() override;
+    void onIdleTimeout(int msec) override;
+    void onProfileLoad() override;
+    void triggerImpl(const QVariantMap &args) override;
+    bool isSupported() override;
 
 public:
-    bool loadAction(const KConfigGroup &config) Q_DECL_OVERRIDE;
+    bool loadAction(const KConfigGroup &config) override;
 
 private Q_SLOTS:
     void onUnavailablePoliciesChanged(PowerDevil::PolicyAgent::RequiredPolicies policies);
