@@ -42,6 +42,8 @@
 #define CONSOLEKIT2_SERVICE "org.freedesktop.ConsoleKit"
 
 class UdevHelper;
+class XRandRXCBHelper;
+class XRandrBrightness;
 class QPropertyAnimation;
 class DDCutilBrightness;
 class Q_DECL_EXPORT PowerDevilUPowerBackend : public PowerDevil::BackendInterface
@@ -97,6 +99,8 @@ private:
 
     // brightness
     QMap<BrightnessControlType, int> m_cachedBrightnessMap;
+    XRandrBrightness         *m_brightnessControl;
+    XRandRXCBHelper *m_randrHelper;
     DDCutilBrightness *m_ddcBrightnessControl;
 
     OrgFreedesktopUPowerInterface *m_upowerInterface;
