@@ -42,9 +42,11 @@
 #include <KConfigGroup>
 #include <KGlobalAccel>
 
+#include <kworkspace.h>
+
 PowerDevilApp::PowerDevilApp(int &argc, char **argv)
     : QGuiApplication(argc, argv)
-    , m_core(Q_NULLPTR)
+    , m_core(nullptr)
 {
     migratePre512KeyboardShortcuts();
 }
@@ -105,7 +107,7 @@ void PowerDevilApp::init()
     if (!instance) {
         qCDebug(POWERDEVIL) << loader->errorString();
         qCCritical(POWERDEVIL) << "KDE Power Management System init failed!";
-        m_core->loadCore(0);
+        m_core->loadCore(nullptr);
         return;
     }
 
@@ -113,7 +115,7 @@ void PowerDevilApp::init()
     if (!interface) {
         qCDebug(POWERDEVIL) << "Failed to cast plugin instance to BackendInterface, check your plugin";
         qCCritical(POWERDEVIL) << "KDE Power Management System init failed!";
-        m_core->loadCore(0);
+        m_core->loadCore(nullptr);
         return;
     }
 
@@ -195,6 +197,7 @@ void PowerDevilApp::migratePre512KeyboardShortcuts()
 int main(int argc, char **argv)
 {
     QGuiApplication::setDesktopSettingsAware(false);
+    KWorkSpace::detectPlatform(argc, argv);
     PowerDevilApp app(argc, argv);
 
     KDBusService service(KDBusService::Unique);
@@ -205,5 +208,3 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
-
-#include "powerdevilapp.moc"
