@@ -30,13 +30,13 @@
 #include <QScrollArea>
 #include <QVBoxLayout>
 
-#include <QtWidgets/QTabWidget>
+#include <QTabWidget>
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusConnectionInterface>
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusReply>
-#include <QtDBus/QDBusServiceWatcher>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusMessage>
+#include <QDBusReply>
+#include <QDBusServiceWatcher>
 
 #include <KAboutData>
 #include <QDebug>
@@ -52,7 +52,7 @@ K_PLUGIN_FACTORY(PowerDevilActivitiesKCMFactory,
 K_EXPORT_PLUGIN(PowerDevilActivitiesKCMFactory("powerdevilactivitiesconfig","powerdevil"))
 
 ActivityPage::ActivityPage(QWidget *parent, const QVariantList &args)
-    : KCModule(0, parent, args)
+    : KCModule(nullptr, parent, args)
     , m_activityConsumer(new KActivities::Consumer(this))
 {
     setButtons(Apply | Help);
